/**
 * Represents a general toolkit error in the AWS CDK Toolkit.
 */
export declare class ToolkitError extends Error {
    /**
     * Determines if a given error is an instance of ToolkitError.
     */
    static isToolkitError(x: any): x is ToolkitError;
    /**
     * Determines if a given error is an instance of AuthenticationError.
     */
    static isAuthenticationError(x: any): x is AuthenticationError;
    /**
     * Determines if a given error is an instance of AssemblyError.
     */
    static isAssemblyError(x: any): x is AssemblyError;
    /**
     * Determines if a given error is an instance of AssemblyError.
     */
    static isContextProviderError(x: any): x is ContextProviderError;
    /**
     * The type of the error, defaults to "toolkit".
     */
    readonly type: string;
    constructor(message: string, type?: string);
}
/**
 * Represents an authentication-specific error in the AWS CDK Toolkit.
 */
export declare class AuthenticationError extends ToolkitError {
    constructor(message: string);
}
/**
 * Represents an authentication-specific error in the AWS CDK Toolkit.
 */
export declare class AssemblyError extends ToolkitError {
    constructor(message: string);
}
/**
 * Represents an error originating from a Context Provider
 */
export declare class ContextProviderError extends ToolkitError {
    constructor(message: string);
}
